==> haskell-esqueleto-3.0.0-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-esqueleto.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: esqueleto
version: 3.0.0
id: esqueleto-3.0.0-8SGsXNshnCpDjJV3b8Whxl
key: esqueleto-3.0.0-8SGsXNshnCpDjJV3b8Whxl
license: BSD-3-Clause
copyright: (c) 2012-2016 Felipe Almeida Lessa
maintainer: cma@bitemyapp.com
author: Felipe Lessa
homepage: https://github.com/bitemyapp/esqueleto
synopsis: Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.
    .
    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)
    .
    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.
    .
    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.
category: Database
abi: 25a36c2b29a8da4a95acc26a5ba8f49e
exposed: True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Internal.Language
    Database.Esqueleto.Internal.Sql Database.Esqueleto.MySQL
    Database.Esqueleto.PostgreSQL Database.Esqueleto.SQLite
hidden-modules: Database.Esqueleto.Internal.Internal
                Database.Esqueleto.Internal.PersistentImport Paths_esqueleto
import-dirs: /usr/lib/ghc-8.6.5/site-local/esqueleto-3.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/esqueleto-3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/esqueleto-3.0.0
hs-libraries: HSesqueleto-3.0.0-8SGsXNshnCpDjJV3b8Whxl
depends:
    base-4.12.0.0 blaze-html-0.9.1.1-6PAyIvh6hy6Ilt6w0CbPFV
    bytestring-0.10.8.2 conduit-1.3.1.1-GP6MsgQ2BS48W03o5Iyugz
    monad-logger-0.3.30-EgbE2RRKSFL3680lxOvGDM
    persistent-2.9.2-9EZpTt94Kvy1LsdPVxHS2D
    resourcet-1.2.2-DSV6hnFiraKK5yk15oWe4c
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 unliftio-0.2.11-HfZ36uDuQPe4HzZMREy7XZ
    unordered-containers-0.2.10.0-FCaPs5fnhYpFgvItTiMoQE
haddock-interfaces: /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html: /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-esqueleto-3.0.0-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-esqueleto.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: esqueleto
version: 3.0.0
id: esqueleto-3.0.0-AUI6VUkvei9IAGNc83pvyQ
key: esqueleto-3.0.0-AUI6VUkvei9IAGNc83pvyQ
license: BSD-3-Clause
copyright: (c) 2012-2016 Felipe Almeida Lessa
maintainer: cma@bitemyapp.com
author: Felipe Lessa
homepage: https://github.com/bitemyapp/esqueleto
synopsis: Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.
    .
    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)
    .
    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.
    .
    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.
category: Database
abi: da974eba8c82b2704359c48595b7af32
exposed: True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Internal.Language
    Database.Esqueleto.Internal.Sql Database.Esqueleto.MySQL
    Database.Esqueleto.PostgreSQL Database.Esqueleto.SQLite
hidden-modules: Database.Esqueleto.Internal.Internal
                Database.Esqueleto.Internal.PersistentImport Paths_esqueleto
import-dirs: /usr/lib/ghc-8.6.5/site-local/esqueleto-3.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/esqueleto-3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/esqueleto-3.0.0
hs-libraries: HSesqueleto-3.0.0-AUI6VUkvei9IAGNc83pvyQ
depends:
    base-4.12.0.0 blaze-html-0.9.1.1-6PAyIvh6hy6Ilt6w0CbPFV
    bytestring-0.10.8.2 conduit-1.3.1.1-7rGn2miUuc0IzsMPA6GM7m
    monad-logger-0.3.30-FPd6De95Z001kt9nMBP22l
    persistent-2.9.2-Gq6x6Lafxo1CoQuiLG1nGe
    resourcet-1.2.2-DSV6hnFiraKK5yk15oWe4c
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 unliftio-0.2.11-HfZ36uDuQPe4HzZMREy7XZ
    unordered-containers-0.2.10.0-8dby3miKFglJ7BLkdgbDGw
haddock-interfaces: /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html: /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
